@@ -1460,9 +1460,9 @@ object_instance_finalize(JSFreeOp  *fop,
 }
 
 static JSObject *
-gjs_lookup_object_prototype_from_info(JSContext    *context,
-                                      GIObjectInfo *info,
-                                      GType         gtype)
+gjs_lookup_object_constructor_from_info(JSContext    *context,
+                                        GIObjectInfo *info,
+                                        GType         gtype)
 {
     JSObject *in_object;
     JSObject *constructor;
@@ -1497,6 +1497,22 @@ gjs_lookup_object_prototype_from_info(JSContext    *context,
 
     g_assert(constructor != NULL);
 
+    return constructor;
+}
+
+static JSObject *
+gjs_lookup_object_prototype_from_info(JSContext    *context,
+                                      GIObjectInfo *info,
+                                      GType         gtype)
+{
+    JSObject *constructor;
+    jsval value;
+
+    constructor = gjs_lookup_object_constructor_from_info(context, info, gtype);
+
+    if (G_UNLIKELY (constructor == NULL))
+        return NULL;
+
     if (!gjs_object_get_property_const(context, constructor,
                                        GJS_STRING_PROTOTYPE, &value))
         return NULL;
@@ -1855,6 +1871,7 @@ gjs_object_define_static_methods(JSContext    *context,
                                  GType         gtype,
                                  GIObjectInfo *object_info)
 {
+    GIStructInfo *gtype_struct;
     int i;
     int n_methods;
 
@@ -1881,6 +1898,26 @@ gjs_object_define_static_methods(JSContext    *context,
 
         g_base_info_unref((GIBaseInfo*) meth_info);
     }
+
+    gtype_struct = g_object_info_get_class_struct(object_info);
+
+    if (gtype_struct == NULL)
+        return JS_TRUE;
+
+    n_methods = g_struct_info_get_n_methods(gtype_struct);
+
+    for (i = 0; i < n_methods; i++) {
+        GIFunctionInfo *meth_info;
+
+        meth_info = g_struct_info_get_method(gtype_struct, i);
+
+        gjs_define_function(context, constructor, gtype,
+                            (GICallableInfo*)meth_info);
+
+        g_base_info_unref((GIBaseInfo*) meth_info);
+    }
+
+    g_base_info_unref((GIBaseInfo*) gtype_struct);
     return JS_TRUE;
 }
 
@@ -1961,9 +1998,6 @@ gjs_define_object_class(JSContext      *context,
         constructor_name = g_type_name(gtype);
     }
 
-    global = JS_GetGlobalObject(context);
-    JSAutoCompartment ac(context, global);
-
     if (!gjs_init_class_dynamic(context, in_object,
                                 parent_proto,
                                 ns, constructor_name,
@@ -2051,16 +2085,10 @@ gjs_object_from_g_object(JSContext    *context,
         gtype = G_TYPE_FROM_INSTANCE(gobj);
         proto = gjs_lookup_object_prototype(context, gtype);
 
-        JS_BeginRequest(context);
-        global = JS_GetGlobalObject(context);
-        JSAutoCompartment ac(context, global);
-
         obj = JS_NewObjectWithGivenProto(context,
                                          JS_GetClass(proto), proto,
                                          gjs_get_import_global (context));
 
-        JS_EndRequest(context);
-
         if (obj == NULL)
             goto out;
 
@@ -2444,6 +2472,7 @@ gjs_object_custom_init(GTypeInstance *instance,
     JSContext *context;
     JSObject *object;
     ObjectInstance *priv;
+    jsval v, r;
 
     object = (JSObject*) object_init_list->data;
     priv = (ObjectInstance*) JS_GetPrivate(object);
@@ -2462,6 +2491,19 @@ gjs_object_custom_init(GTypeInstance *instance,
     context = (JSContext*) gjs_context_get_native_context(gjs_context);
 
     associate_js_gobject(context, object, G_OBJECT (instance));
+
+    if (!gjs_object_get_property_const(context, object,
+                                       GJS_STRING_INSTANCE_INIT, &v)) {
+        gjs_log_exception(context);
+        return;
+    }
+
+    if (!JSVAL_IS_OBJECT(v) || JSVAL_IS_NULL(v))
+        return;
+
+    if (!JS_CallFunctionValue(context, object, v,
+                              0, NULL, &r))
+        gjs_log_exception(context);
 }
 
 static inline void
@@ -2643,7 +2685,7 @@ gjs_signal_new(JSContext *cx,
     GSignalAccumulator accumulator;
     gint signal_id;
     guint i, n_parameters;
-    GType *params;
+    GType *params, return_type;
     JSBool ret;
 
     if (argc != 6)
@@ -2673,8 +2715,9 @@ gjs_signal_new(JSContext *cx,
         accumulator = NULL;
     }
 
-    if (accumulator == g_signal_accumulator_true_handled &&
-        JSVAL_TO_INT(argv[4]) != G_TYPE_BOOLEAN) {
+    return_type = gjs_gtype_get_actual_gtype(cx, JSVAL_TO_OBJECT(argv[4]));
+
+    if (accumulator == g_signal_accumulator_true_handled && return_type != G_TYPE_BOOLEAN) {
         gjs_throw (cx, "GObject.SignalAccumulator.TRUE_HANDLED can only be used with boolean signals");
         ret = JS_FALSE;
         goto out;
@@ -2706,7 +2749,7 @@ gjs_signal_new(JSContext *cx,
                               accumulator,
                               NULL, /* accu_data */
                               g_cclosure_marshal_generic,
-                              gjs_gtype_get_actual_gtype(cx, JSVAL_TO_OBJECT(argv[4])), /* return type */
+                              return_type, /* return type */
                               n_parameters,
                               params);
 
@@ -2743,3 +2786,29 @@ gjs_define_private_gi_stuff(JSContext *context,
 
     return JS_TRUE;
 }
+
+JSBool
+gjs_lookup_object_constructor(JSContext *context,
+                              GType      gtype,
+                              jsval     *value_p)
+{
+    JSObject *constructor;
+    GIObjectInfo *object_info;
+
+    object_info = (GIObjectInfo*)g_irepository_find_by_gtype(NULL, gtype);
+
+    g_assert(object_info == NULL ||
+             g_base_info_get_type((GIBaseInfo*)object_info) ==
+             GI_INFO_TYPE_OBJECT);
+
+    constructor = gjs_lookup_object_constructor_from_info(context, object_info, gtype);
+
+    if (G_UNLIKELY (constructor == NULL))
+        return JS_FALSE;
+
+    if (object_info)
+        g_base_info_unref((GIBaseInfo*)object_info);
+
+    *value_p = OBJECT_TO_JSVAL(constructor);
+    return JS_TRUE;
+}
