@@ -453,11 +453,15 @@ _gjs_log_info_usage(GIBaseInfo *info)
 JSBool
 gjs_define_info(JSContext  *context,
                 JSObject   *in_object,
-                GIBaseInfo *info)
+                GIBaseInfo *info,
+                gboolean   *defined)
 {
 #if GJS_VERBOSE_ENABLE_GI_USAGE
     _gjs_log_info_usage(info);
 #endif
+
+    *defined = TRUE;
+
     switch (g_base_info_get_type(info)) {
     case GI_INFO_TYPE_FUNCTION:
         {
@@ -492,6 +496,16 @@ gjs_define_info(JSContext  *context,
         }
         break;
     case GI_INFO_TYPE_STRUCT:
+        /* We don't want GType structures in the namespace,
+           we expose their fields as vfuncs and their methods
+           as static methods
+        */
+        if (g_struct_info_is_gtype_struct((GIStructInfo*) info)) {
+            *defined = FALSE;
+            break;
+        }
+        /* Fall through */
+
     case GI_INFO_TYPE_BOXED:
         gjs_define_boxed_class(context, in_object, (GIBoxedInfo*) info);
         break;
@@ -749,8 +763,8 @@ gjs_hyphen_from_camel(const char *camel_name)
 }
 
 JSObject *
-gjs_lookup_generic_prototype(JSContext  *context,
-                             GIBaseInfo *info)
+gjs_lookup_generic_constructor(JSContext  *context,
+                               GIBaseInfo *info)
 {
     JSObject *in_object;
     JSObject *constructor;
@@ -772,6 +786,20 @@ gjs_lookup_generic_prototype(JSContext  *context,
     constructor = JSVAL_TO_OBJECT(value);
     g_assert(constructor != NULL);
 
+    return constructor;
+}
+
+JSObject *
+gjs_lookup_generic_prototype(JSContext  *context,
+                             GIBaseInfo *info)
+{
+    JSObject *constructor;
+    jsval value;
+
+    constructor = gjs_lookup_generic_constructor(context, info);
+    if (G_UNLIKELY (constructor == NULL))
+        return NULL;
+
     if (!gjs_object_get_property_const(context, constructor,
                                        GJS_STRING_PROTOTYPE, &value))
         return NULL;
