@@ -64,21 +64,19 @@ GJS_DEFINE_PRIV_FROM_JS(Union, gjs_union_class)
  */
 static JSBool
 union_new_resolve(JSContext *context,
-                  JSObject **obj,
-                  jsid      *id,
-                  unsigned   flags,
-                  JSObject **objp)
+                  JS::HandleObject obj,
+                  JS::HandleId id,
+                  unsigned flags,
+                  JS::MutableHandleObject objp)
 {
     Union *priv;
     char *name;
     JSBool ret = JS_TRUE;
 
-    *objp = NULL;
-
-    if (!gjs_get_string_id(context, *id, &name))
+    if (!gjs_get_string_id(context, id, &name))
         return JS_TRUE; /* not resolved, but no error */
 
-    priv = priv_from_js(context, *obj);
+    priv = priv_from_js(context, obj);
     gjs_debug_jsprop(GJS_DEBUG_GBOXED, "Resolve prop '%s' hook obj %p priv %p", name, *obj, priv);
 
     if (priv == NULL) {
@@ -109,7 +107,7 @@ union_new_resolve(JSContext *context,
                           g_base_info_get_namespace( (GIBaseInfo*) priv->info),
                           g_base_info_get_name( (GIBaseInfo*) priv->info));
 
-                union_proto = *obj;
+                union_proto = obj;
 
                 if (gjs_define_function(context, union_proto,
                                         g_registered_type_info_get_g_type(priv->info),
@@ -119,7 +117,7 @@ union_new_resolve(JSContext *context,
                     goto out;
                 }
 
-                *objp = union_proto; /* we defined the prop in object_proto */
+                objp.set(union_proto); /* we defined the prop in object_proto */
             }
 
             g_base_info_unref( (GIBaseInfo*) method_info);
