@@ -581,7 +581,7 @@ function _BranchTracker(branchCounters) {
             this._activeBranch = nextActiveBranch;
             this._activeBranch.hit = true;
         }
-    }
+    };
 }
 
 function _convertFunctionCountersToArray(functionCounters) {
@@ -640,6 +640,10 @@ function CoverageStatisticsContainer(files) {
         return coveredFiles[filename];
     }
 
+    this.getCoveredFiles = function() {
+        return Object.keys(coveredFiles);
+    };
+
     this.fetchStatistics = function(filename) {
         let statistics = ensureStatisticsFor(filename);
         if (statistics === undefined)
@@ -661,6 +665,10 @@ function CoverageStatistics(files) {
      * a separate compartment inside of coverage.cpp */
     this.dbg = new Debugger(debuggee);
 
+    this.getCoveredFiles = function() {
+        return this.container.getCoveredFiles();
+    };
+
     this.getNumberOfLinesFor = function(filename) {
         return fetchStatistics(filename).nLines;
     };
@@ -721,7 +729,7 @@ function CoverageStatistics(files) {
                                          });
 
             this._branchTracker.incrementBranchCounters(offsetLine);
-        }
+        };
 
         return undefined;
     };
